@@ -381,10 +381,15 @@ class SeleniumDriverCore(object):
 
         # Run the standard selector
         try:
-            driver_element = find_method(args)
+            driver_element = find_method(*args)
             if driver_element:
-                key = self._upload_screenshot_if_necessary(element_name)
-                self._update_elem(driver_element, key, element_name)
+                try:
+                    key = self._upload_screenshot_if_necessary(element_name)
+                    if key is not None:
+                        # Key is None when element is frozen or another issue during screenshot and upload.
+                        self._update_elem(driver_element, key, element_name)
+                except Exception:
+                    log.error('error uploading screenshot to devtools. Continuing.')
             return driver_element
         except NoElementFoundException as e:
             log.exception(e)
@@ -466,8 +471,19 @@ class SeleniumDriverCore(object):
             log.error(r['message'])
         return r
 
+    def _check_frozen(self, element_name):
+        url = self.url + '/check_frozen'
+        request_data = {'api_key': self.api_key,
+                        'label': element_name
+                        }
+        resp = requests.post(url, json=request_data).json()
+        return resp.get('is_frozen', True)
+
 
     def _upload_screenshot_if_necessary(self, element_name):
+        if self._check_frozen(element_name):
+            return None
+
         screenshotBase64 = self._get_screenshot()
         screenshot_uuid = self.get_screenshot_hash(screenshotBase64)
         # Check results
